# sys-detection

https://pypi.org/project/llvm-installer/

Helps installing pre-built LLVM packages for various operating systems.

## Usage as module


## Command-line usage

```bash
python3 -m llvm_installer
```
